<?php
/**
 * Plugin Name: WooCommerce Cart Dynamic Tags for Elementor
 * Plugin URI:  https://codedesign.tips/
 * Description: Adds WooCommerce cart items as dynamic tags for Elementor.
 * Version:     1.1
 * Author:      codedesign.tips - Jerome Mosca
 * Author URI:  https://codedesign.tips/
 * License:     GPL2
 * Text Domain: wc-cart-dynamic-tags
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// Check if Elementor is active
function wc_cart_dynamic_tags_check() {
    if (!did_action('elementor/loaded') || !class_exists('WooCommerce')) {
        add_action('admin_notices', function() {
            echo '<div class="notice notice-warning"><p>WooCommerce Cart Dynamic Tags requires Elementor and WooCommerce to be installed and active.</p></div>';
        });
        return;
    }
}
add_action('plugins_loaded', 'wc_cart_dynamic_tags_check');

// FIX: Ensure WooCommerce Cart Session Starts Properly
function wc_cart_dynamic_tags_fix_session() {
    if (!session_id() && !headers_sent()) {
        session_start();
    }

    if (class_exists('WooCommerce') && function_exists('WC') && WC()->session) {
        WC()->session->set_customer_session_cookie(true);
    }
}
add_action('wp_loaded', 'wc_cart_dynamic_tags_fix_session', 10);

// Include the Dynamic Tags Class
include_once plugin_dir_path(__FILE__) . 'includes/class-wc-cart-dynamic-tags.php';

function wc_cart_dynamic_tags_scripts() {
    wp_enqueue_script('wc-cart-dynamic-tags-js', plugin_dir_url(__FILE__) . 'assets/cart-update.js', ['jquery'], null, true);
    wp_localize_script('wc-cart-dynamic-tags-js', 'wcCartData', ['ajaxurl' => admin_url('admin-ajax.php')]);
}
add_action('wp_enqueue_scripts', 'wc_cart_dynamic_tags_scripts');
